@@ -57,7 +57,7 @@ class IotToLambda(
         :param id: - this is a a scope-unique id.
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default props are used
 
         :access: public
         :since: 0.8.0
@@ -106,7 +106,7 @@ class IotToLambdaProps:
         '''
         :param iot_topic_rule_props: User provided CfnTopicRuleProps to override the defaults. Default: - None
         :param existing_lambda_obj: Optional - instance of an existing Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
-        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` is an error. Default: - Default props are used
+        :param lambda_function_props: Optional - user provided props to override the default props for the Lambda function. Providing both this and ``existingLambdaObj`` causes an error. Default: - Default props are used
 
         :summary: The properties for the IotToLambda class.
         '''
@@ -154,7 +154,8 @@ class IotToLambdaProps:
     ) -> typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps]:
         '''Optional - user provided props to override the default props for the Lambda function.
 
-        Providing both this and ``existingLambdaObj`` is an error.
+        Providing both this and ``existingLambdaObj``
+        causes an error.
 
         :default: - Default props are used
         '''
